@@ -1,7 +1,10 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # coding: utf-8
 
-from __future__ import unicode_literals
+import sys
+
+if sys.version_info[0] == 2:
+    sys.exit('haruhi-dl no longer works on Python 2, use Python 3 instead')
 
 __license__ = 'LGPL-3.0-or-later'
 
@@ -9,7 +12,6 @@ import codecs
 import io
 import os
 import random
-import sys
 
 
 from .options import (
@@ -340,6 +342,7 @@ def _real_main(argv=None):
         'format': opts.format,
         'listformats': opts.listformats,
         'outtmpl': outtmpl,
+        'outtmpl_na_placeholder': opts.outtmpl_na_placeholder,
         'autonumber_size': opts.autonumber_size,
         'autonumber_start': opts.autonumber_start,
         'restrictfilenames': opts.restrictfilenames,
